SpacingBreakpoints class

Defines width thresholds used to classify screens into ScreenType.

Annotations

Constructors

SpacingBreakpoints({double compact = 600.0, double medium = 840.0, double expanded = 1200.0, double large = 1600.0})
Creates a SpacingBreakpoints configuration.
const

Properties

compact → double
Maximum width for compact screens (default 600.0).
final
expanded → double
Maximum width for expanded screens (default 1200.0).
final
hashCode → int
The hash code for this object.
no setteroverride
large → double
Maximum width for large screens (default 1600.0).
final
medium → double
Maximum width for medium screens (default 840.0).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(double width) → ScreenType
Resolves the ScreenType for a given screen width.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override