responsive_spacing_v2 library
Classes
- ResponsiveMargin
- A widget that adds responsive margin around its child based on the screen width.
- ResponsivePadding
- A widget that adds responsive padding around its child based on the screen width.
- ResponsiveSpacer
- A widget that adds responsive spacing between widgets based on a size key.
- ResponsiveSpacing
- A utility class that defines a scale of responsive spacing values.
- ResponsiveSpacingProvider
- Provides responsive spacing values (e.g., xs, sm, md, lg, xl, xxl) and breakpoint information to descendant widgets.
-
ResponsiveValue<
T> -
Resolves a value of type
Tbased on the current screen size. - SliverResponsivePadding
- A sliver that adds responsive padding around another sliver.
- SliverResponsiveSpacer
- A sliver that adds responsive space in a CustomScrollView.
- SpacingBreakpoints
- Defines width thresholds used to classify screens into ScreenType.
Enums
- ScreenType
- Screen classification based on standard responsive layout breakpoints.
- SpacingSize
- Predefined spacing size keys for type-safe responsive spacing.
Extensions
- ResponsiveContextExtension on BuildContext
- Convenience extensions on BuildContext for responsive layout access.
- SpacingExtension on BuildContext
- Extension on BuildContext to access ResponsiveSpacing easily.
- SpacingNumExtension on num
- Extension on num to quickly build vertical and horizontal spacing widgets.