ResponsiveSpacingProvider class
Provides responsive spacing values (e.g., xs, sm, md, lg, xl) to descendant widgets using an inherited context.
You can customize the base unit and scale factor for spacing.
Example usage:
ResponsiveSpacingProvider(
base: 8.0,
scale: 1.5,
child: MyApp(),
);
Access spacing values via:
context.spacing.md
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ResponsiveSpacingProvider
Constructors
- ResponsiveSpacingProvider({Key? key, required Widget child, double base = 4.0, double scale = 1.5})
-
Creates a ResponsiveSpacingProvider.
const
Properties
- base → double
-
The base unit for spacing. Default is
4.0.final - child → Widget
-
The widget subtree that will have access to the spacing values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
The scale multiplier for spacing values. Default is
1.5.final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ResponsiveSpacingProvider> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → ResponsiveSpacing - Retrieves the ResponsiveSpacing from the closest ancestor.